==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/desktop_docking/translations/desktop_docking_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Papierkorb</translation>
    </message>
    <message>
        <source>Desktop Docking</source>
        <translation>Desktop Docking</translation>
    </message>
    <message>
        <source>Horizontal position</source>
        <translation>Horizontale Position</translation>
    </message>
    <message>
        <source>Vertical position</source>
        <translation>Vertikale Position</translation>
    </message>
    <message>
        <source>Transparent</source>
        <translation>Transparent</translation>
    </message>
    <message>
        <source>Background color</source>
        <translation>Hintergrundfarbe</translation>
    </message>
    <message>
        <source>Enable Move entry in docklet&apos;s menu</source>
        <translation>Verschiebung eines Eintrages im Docklet Menü ermöglichen</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Bewegen</translation>
    </message>
    <message>
        <source>Enable icon moving on desktop. After pressing move cursor over docking icon and then move. Press any mouse key when the icon is in right place.</source>
        <translation>Verschiebung eines Icons auf dem Desktop ermöglichen. Nach Drücken bewege den Mauszeiger über das angedockte Icon und bewege es anschließend. Drücke irgendeine Maustaste wenn das Icon am gewünschten Platz ist.</translation>
    </message>
</context>
<context>
    <name>DesktopDock</name>
    <message>
        <source>Move</source>
        <translation>Bewegen</translation>
    </message>
</context>
</TS>

==> kadu_1.0.orig.tar.bz2: kadu-1.0/plugins/desktop_docking/translations/desktop_docking_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation>Papierkorb</translation>
    </message>
    <message>
        <source>Desktop Docking</source>
        <translation>Desktop Docking</translation>
    </message>
    <message>
        <source>Horizontal position</source>
        <translation>Horizontale Position</translation>
    </message>
    <message>
        <source>Vertical position</source>
        <translation>Vertikale Position</translation>
    </message>
    <message>
        <source>Transparent</source>
        <translation>Transparent</translation>
    </message>
    <message>
        <source>Background color</source>
        <translation>Hintergrundfarbe</translation>
    </message>
    <message>
        <source>Enable Move entry in docklet&apos;s menu</source>
        <translation>Verschiebung eines Eintrages im Docklet Menü ermöglichen</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Bewegen</translation>
    </message>
    <message>
        <source>Enable icon moving on desktop. After pressing move cursor over docking icon and then move. Press any mouse key when the icon is in right place.</source>
        <translation>Verschiebung eines Icons auf dem Desktop ermöglichen. Nach Drücken bewege den Mauszeiger über das angedockte Icon und bewege es anschließend. Drücke irgendeine Maustaste wenn das Icon am gewünschten Platz ist.</translation>
    </message>
    <message>
        <source>Buddies list</source>
        <translation>Kontaktliste</translation>
    </message>
</context>
<context>
    <name>DesktopDock</name>
    <message>
        <source>Move</source>
        <translation>Bewegen</translation>
    </message>
</context>
</TS>
